]> granicus.if.org Git - neomutt/commitdiff
Fix sidebar references to the "new count" to be "unread". (closes #3908)
authorKevin McCarthy <kevin@8t8.us>
Thu, 19 Jan 2017 22:58:13 +0000 (14:58 -0800)
committerRichard Russon <rich@flatcap.org>
Fri, 10 Feb 2017 03:32:55 +0000 (03:32 +0000)
%N in $sidebar_format and "new"in $sidebar_sort_method actually use
the unread message count.  Update the documentation to mention that.

Add an "unread" method to $sidebar_sort_method, but preserve "new" for
compatibility.

Change the SORT_COUNT_NEW constant to SORT_UNREAD, so the code is also
consistent with the meaning.

Thanks to cri for reporting the problem and suggesting where to fix it
in the code.

browser.c
doc/manual.xml.head
init.h
sidebar.c
sort.h

index 7e31f614def9bbcaf0fbb549a5dd8d41c88e4d3a..1eb232408be1db529668ca9e87ada03c94dba644 100644 (file)
--- a/browser.c
+++ b/browser.c
@@ -197,7 +197,7 @@ static int browser_compare (const void *a, const void *b)
       return browser_compare_desc(a, b);
     case SORT_COUNT:
       return browser_compare_count(a, b);
-    case SORT_COUNT_NEW:
+    case SORT_UNREAD:
       return browser_compare_count_new(a, b);
     case SORT_SUBJECT:
     default:
@@ -1751,7 +1751,7 @@ void _mutt_select_file (char *f, size_t flen, int flags, char ***files, int *num
              break;
 
             case 6: /* ne(w) count */
-             BrowserSort = SORT_COUNT_NEW;
+             BrowserSort = SORT_UNREAD;
              break;
 
             case 7: /* do(n)'t sort */
index d5aace162cea5901afcead191852bbca88e1cd21..c9d2c37bab1f72209f07b564a3a6afb0a79aa903 100644 (file)
@@ -13409,12 +13409,16 @@ set sort_browser="reverse-size"
           </row>
           <row>
             <entry><literal>new</literal></entry>
-            <entry>Number of new messages</entry>
+            <entry>Number of unread messages</entry>
           </row>
           <row>
             <entry><literal>path</literal></entry>
             <entry>Alphabetically by path</entry>
           </row>
+          <row>
+            <entry><literal>unread</literal></entry>
+            <entry>Number of unread messages</entry>
+          </row>
           <row>
             <entry><literal>unsorted</literal></entry>
             <entry>Order of the <literal>mailboxes</literal> command</entry>
--- a/sidebar.c
+++ b/sidebar.c
@@ -310,7 +310,7 @@ static int cb_qsort_sbe (const void *a, const void *b)
     case SORT_COUNT:
       result = (b2->msg_count - b1->msg_count);
       break;
-    case SORT_COUNT_NEW:
+    case SORT_UNREAD:
       result = (b2->msg_unread - b1->msg_unread);
       break;
     case SORT_DESC:
@@ -421,7 +421,7 @@ static void sort_entries (void)
 
   /* These are the only sort methods we understand */
   if ((ssm == SORT_COUNT)     ||
-      (ssm == SORT_COUNT_NEW) ||
+      (ssm == SORT_UNREAD)    ||
       (ssm == SORT_FLAGGED)   ||
       (ssm == SORT_PATH))
     qsort (Entries, EntryCount, sizeof (*Entries), cb_qsort_sbe);
diff --git a/sort.h b/sort.h
index 4242e9dce21ff48e2b8e966b134148e9cc2a646b..b2c35cfd4d6f5d73537d33625fbfa0e0cda8e7d2 100644 (file)
--- a/sort.h
+++ b/sort.h
 #define SORT_TRUST     13
 #define SORT_SPAM      14
 #define SORT_COUNT     15
-#define SORT_COUNT_NEW 16
+#define SORT_UNREAD    16
 #define SORT_FLAGGED   17
 #define SORT_PATH      18
-#define SORT_DESC      19
-#define SORT_LABEL     20
+#define SORT_LABEL     19
+#define SORT_DESC      20
 
 /* Sort and sort_aux are shorts, and are a composite of a
  * constant sort operation number and a set of compounded
diff --git a/init.h b/init.h
index 0791d51866e72a6956f68e6ce0de338705df9357..9375adadb22564c8cc94d5629c2716df7da7203b 100644 (file)
--- a/init.h
+++ b/init.h
@@ -3174,7 +3174,7 @@ struct option_t MuttVars[] = {
   ** .dl
   ** .dt %B  .dd Name of the mailbox
   ** .dt %S  .dd * Size of mailbox (total number of messages)
** .dt %N  .dd * Number of New messages in the mailbox
   ** .dt %n  .dd N if mailbox has new mail, blank otherwise
   ** .dt %F  .dd * Number of Flagged messages in the mailbox
   ** .dt %!  .dd ``!'' : one flagged message;
@@ -3250,7 +3250,10 @@ struct option_t MuttVars[] = {
   ** .dd alpha (alphabetically)
   ** .dd count (all message count)
   ** .dd flagged (flagged message count)
-  ** .dd new (new message count)
+  ** .dd name (alphabetically)
+  ** .dd new (unread message count)
+  ** .dd path (alphabetically)
+  ** .dd unread (unread message count)
   ** .dd unsorted
   ** .ie
   ** .pp
@@ -4347,7 +4350,7 @@ const struct mapping_t SortBrowserMethods[] = {
   { "count",   SORT_COUNT },
   { "date",    SORT_DATE },
   { "desc",    SORT_DESC },
-  { "new",     SORT_COUNT_NEW },
+  { "new",     SORT_UNREAD },
   { "size",    SORT_SIZE },
   { "unsorted",        SORT_ORDER },
   { NULL,       0 }
@@ -4375,8 +4378,9 @@ const struct mapping_t SortSidebarMethods[] = {
   { "flagged",         SORT_FLAGGED },
   { "mailbox-order",   SORT_ORDER },
   { "name",            SORT_PATH },
-  { "new",             SORT_COUNT_NEW },
+  { "new",             SORT_UNREAD },  /* kept for compatibility */
   { "path",            SORT_PATH },
+  { "unread",          SORT_UNREAD },
   { "unsorted",                SORT_ORDER },
   { NULL,              0 }
 };
@@ -3174,7 +3174,7 @@ struct option_t MuttVars[] = {
   ** .dt %B  .dd Name of the mailbox
   ** .dt %S  .dd * Size of mailbox (total number of messages)
-  ** .dt %N  .dd * Number of New messages in the mailbox
+  ** .dt %N  .dd * Number of unread messages in the mailbox
   ** .dt %n  .dd N if mailbox has new mail, blank otherwise
   ** .dt %F  .dd * Number of Flagged messages in the mailbox
index 9c7bd852b3146fb9a3602ab3e1d23f434a0a715b..022dc597a42a15bf30b805d721cca8eb3958c318 100644 (file)